@@ -23,7 +23,7 @@ use WebService::DMM::Series;
 
 use utf8;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 my $agent_name = __PACKAGE__ . "/$VERSION";
 our $UserAgent = Furl->new(agent => $agent_name);
@@ -172,6 +172,11 @@ sub _format_current_time {
     strftime '%Y-%m-%d %T', localtime;
 }
 
+sub last_response {
+    my $self = shift;
+    $self->{_last_response};
+}
+
 sub _send_request {
     my ($self, %args)  = @_;
 
@@ -186,7 +191,7 @@ sub _send_request {
     $self->{_site} = $args{site}; # need for parsing actor information
 
     my $response = $self->_parse_response( \$res->content );
-    $response->last_response($res);
+    $self->{_last_response} = $res;
     return $response;
 }
 
@@ -520,7 +525,7 @@ API ID of DMM. Register your account in DMM and you can get API ID.
 
 =head2 Instance Method
 
-=head3 $dmm->search(%param)
+=head3 $dmm->search(%param) : WebService::DMM::Response
 
 I<%params> mandatory parameters are:
 
@@ -574,6 +579,10 @@ Keyword should be string(not byte sequence).
 
 =back
 
+=head3 $dmm->last_response : Furl::Response
+
+Return last response which is a Furl::Response instance.
+
 =head1 SERVICE AND FLOOR
 
 DMM.com services are:
